@@ -15,11 +15,11 @@ from spandrel import ModelDescriptor, ModelLoader
 def onnx_to_onnx_dynamic(input_path: str, output_path: str, opset: int | None = None, irver: int | None = None) -> None:
     m = onnx.load(input_path)
 
-    # --- バッチ次元を書き換え（1→-1） ---------------------------
+    # --- Rewrite batch dimension (1→-1) ---------------------------
     for v in chain(m.graph.input, m.graph.output):
         v.type.tensor_type.shape.dim[0].dim_param = "N"
 
-    # --- shape 推論 → 最小限の最適化 ----------------------------
+    # --- Shape inference → minimal optimization ----------------------------
     m = onnx.shape_inference.infer_shapes(m)
     g = gs.import_onnx(m).toposort().cleanup()
     m2 = gs.export_onnx(g)
@@ -44,7 +44,7 @@ def onnx_to_onnx_dynamic(input_path: str, output_path: str, opset: int | None =
     print(f"Graph inputs: {[i.name for i in m2.graph.input]}")
     print(f"Graph outputs: {[o.name for o in m2.graph.output]}")
 
-    # --- 最終チェック -------------------------------------------
+    # --- Final check -------------------------------------------
     onnx.checker.check_model(m2)
     onnx.save(m2, output_path)
 
@@ -66,25 +66,25 @@ def check_torch_model(model_path: str) -> None:
         model_desc: ModelDescriptor = ModelLoader().load_from_file(model_path)
         print(f"✅ Valid PyTorch model found at: {model_path}")
 
-        # アーキテクチャ情報
+        # Architecture information
         print(f"\n🏗️ Architecture: {model_desc.architecture.name}")
         print(f"   ID: {model_desc.architecture.id}")
         print(f"   Purpose: {model_desc.purpose}")
 
-        # モデル特性
+        # Model properties
         print("\n📊 Model Properties:")
         print(f"   Scale: {model_desc.scale}x")
         print(f"   Input channels: {model_desc.input_channels}")
         print(f"   Output channels: {model_desc.output_channels}")
         print(f"   Tiling support: {model_desc.tiling.name}")
 
-        # 精度サポート
+        # Precision support
         print("\n🎯 Precision Support:")
         print(f"   FP16: {'✅' if model_desc.supports_half else '❌'}")
         print(f"   BF16: {'✅' if model_desc.supports_bfloat16 else '❌'}")
         print("   FP32: ✅")
 
-        # サイズ要件の分析
+        # Size requirements analysis
         size_req = model_desc.size_requirements
         print("\n📏 Size Requirements:")
         print(f"   Minimum size: {size_req.minimum} pixels")
@@ -96,15 +96,15 @@ def check_torch_model(model_path: str) -> None:
         else:
             print("   ⚠️ Has size constraints")
 
-        # 推奨入力サイズ範囲の計算
+        # Calculate recommended input size ranges
         print("\n🎯 Recommended Input Size Ranges:")
 
-        # 最小サイズの計算
+        # Calculate minimum size
         min_size = max(64, size_req.minimum)
         if size_req.multiple_of > 1:
             min_size = ((min_size - 1) // size_req.multiple_of + 1) * size_req.multiple_of
 
-        # 最適サイズの計算
+        # Calculate optimal sizes
         optimal_sizes = [512, 768, 1024]
         valid_optimal = []
         for size in optimal_sizes:
@@ -114,7 +114,7 @@ def check_torch_model(model_path: str) -> None:
             if adjusted >= size_req.minimum:
                 valid_optimal.append(adjusted)
 
-        # 最大サイズの計算
+        # Calculate maximum size
         max_size = 4096
         if size_req.multiple_of > 1:
             max_size = (max_size // size_req.multiple_of) * size_req.multiple_of
@@ -126,7 +126,7 @@ def check_torch_model(model_path: str) -> None:
         if size_req.square:
             print("   ⚠️ Model requires square input (width == height)")
 
-        # タイリング推奨事項
+        # Tiling recommendations
         print("\n🧩 Tiling Recommendations:")
         if model_desc.tiling.name == "SUPPORTED":
             print("   ✅ Tiling supported - safe for large images")
@@ -138,7 +138,7 @@ def check_torch_model(model_path: str) -> None:
             print("   🔄 Model handles tiling internally")
             print("   💡 Do not tile externally - process full images")
 
-        # ONNX変換用の推奨設定
+        # Recommended settings for ONNX conversion
         print("\n🚀 ONNX Export Recommendations:")
         recommended_shape = (
             1,
@@ -149,7 +149,7 @@ def check_torch_model(model_path: str) -> None:
         print(f"   Recommended input_shape: {recommended_shape}")
         print("   Dynamic axes suggested for flexible sizing")
 
-        # Tags情報
+        # Tags information
         if model_desc.tags:
             print(f"\n🏷️ Model Tags: {', '.join(model_desc.tags)}")
 
@@ -178,26 +178,26 @@ def check_onnx_model(model_path: str) -> None:
         print(f"   Model Version: {model.model_version}")
         print(f"   Domain: {model.domain}")
 
-        # 入力情報の分析
+        # Input information analysis
         for i, input_info in enumerate(model.graph.input):
             print(f"\n📥 Input {i}: {input_info.name}")
             print(f"   Data Type: {onnx.TensorProto.DataType.Name(input_info.type.tensor_type.elem_type)}")
 
-            # 入力の形状を分析
+            # Analyze input shape
             shape_info = input_info.type.tensor_type.shape
             shape_str = []
             dynamic_dims = []
 
             for dim_idx, dim in enumerate(shape_info.dim):
                 if dim.HasField("dim_value"):
-                    # 固定サイズ
+                    # Fixed size
                     shape_str.append(str(dim.dim_value))
                 elif dim.HasField("dim_param"):
-                    # パラメータ名による動的サイズ
+                    # Dynamic size by parameter name
                     shape_str.append(f"{dim.dim_param}")
                     dynamic_dims.append((dim_idx, dim.dim_param))
                 else:
-                    # 制約なし動的サイズ
+                    # Unconstrained dynamic size
                     shape_str.append("?")
                     dynamic_dims.append((dim_idx, "unconstrained"))
 
@@ -208,7 +208,7 @@ def check_onnx_model(model_path: str) -> None:
                 for dim_idx, dim_name in dynamic_dims:
                     print(f"      Axis {dim_idx}: {dim_name}")
 
-                    # 制約情報の推測（一般的なパターン）
+                    # Infer constraint information (common patterns)
                     if dim_idx == 0:
                         print("         💡 Likely batch dimension (typical range: 1-16)")
                     elif dim_idx == 1:
@@ -252,6 +252,28 @@ def check_onnx_model(model_path: str) -> None:
         raise RuntimeError(f"Failed to load ONNX model: {e}")
 
 
+def check_trt_model(
+    engine_path: str,
+    verbose: bool = False,
+) -> None:
+    print(f"Checking TensorRT model: {engine_path}")
+    if not os.path.exists(engine_path):
+        raise FileNotFoundError(f"{engine_path} does not exist")
+
+    with open(engine_path, "rb") as f:
+        model_bytes = f.read()
+
+    logger = trt.Logger(trt.Logger.WARNING)
+    runtime = trt.Runtime(logger)
+    engine = runtime.deserialize_cuda_engine(model_bytes)
+    engine.create_execution_context()
+
+    for name in engine:
+        input_shape = engine.get_tensor_shape(name)
+        input_dtype = engine.get_tensor_dtype(name)
+        print(f"Input: Tensor: {name}, Shape: {input_shape}, Type: {trt.nptype(input_dtype)}")
+
+
 def torch_to_onnx(
     model_path: str,
     onnx_path: str,
@@ -349,6 +371,8 @@ def onnx_to_trt_dynamic_shape(
     spatial_range  : Tuple (min,opt,max) applied to H/W (axes ≥2) when they are -1
     verbose        : If True, TensorRT logger prints INFO messages
     """
+    print("------------------ ONNX to TensorRT Dynamic Shape Conversion -----------------")
+    print(f"Building TensorRT engine from ONNX model: {onnx_path}")
     if not os.path.exists(onnx_path):
         raise FileNotFoundError(f"{onnx_path} does not exist")
 
@@ -365,19 +389,13 @@ def onnx_to_trt_dynamic_shape(
                 print(parser.get_error(i), file=sys.stderr)
             raise RuntimeError("Failed to parse ONNX model")
 
-    # ----------------- Check ONNX model -----------------
-    # m = onnx.load(onnx_path)
-    # --- バッチ次元を書き換え（1→-1） ---------------------------
-    # for v in chain(m.graph.input, m.graph.output):
-    #    v.type.tensor_type.shape.dim[0].dim_param = "N"
-
-    # --- shape 推論 → 最小限の最適化 ----------------------------
-    # m = onnx.shape_inference.infer_shapes(m)
-    # g = gs.import_onnx(m).toposort().cleanup()
-
-    # --- 最終チェック -------------------------------------------
-    # onnx.checker.check_model(m)
-    # onnx.save(gs.export_onnx(g), onnx_path)
+        m = onnx.load(onnx_path)
+        print(f"ONNX model opset version: {m.opset_import[0].version}, ir_version: {m.ir_version}")
+        print(f"ONNX model inputs: {[i.name for i in m.graph.input]}")
+        print(f"ONNX model outputs: {[o.name for o in m.graph.output]}")
+        print(f"ONNX model nodes: {len(m.graph.node)}")
+        print(f"ONNX model initializers: {[i.name for i in m.graph.initializer]}")
+        print(f"ONNX model ops: {[n.op_type for n in m.graph.node]}")
 
     # ----------------- Build-time flags -----------------
     config = builder.create_builder_config()
@@ -446,175 +464,10 @@ def onnx_to_trt_dynamic_shape(
     print(f"✓ Engine written to {engine_path}")
 
 
-def _onnx_to_trt_dynamic_shape(
-    onnx_path: str,
-    engine_path: str,
-    precision: str = "fp16",
-    workspace: int = 1024 << 20,  # 1024MB
-    size_requirements: tuple = (16, 512, 2048),  # Conservative sizes
-    batch_requirements: tuple = (1, 1, 1),
-) -> None:
-    """
-    Convert ONNX upscale model to TensorRT engine with optimization profile for dynamic shapes.
-
-    ⚠️ WARNING: Transformer-based models (DAT, SwinIR, etc.) may not be compatible with TensorRT
-    due to unsupported operations like complex attention mechanisms, dynamic reshaping, etc.
-    Consider using PyTorch inference instead for such models.
-
-    Args:
-        onnx_path: Path to input ONNX model
-        engine_path: Path to output TensorRT engine
-        precision: Precision mode ('fp16', 'fp32', 'int8')
-        workspace: Workspace size in bytes
-        size_requirements: Tuple of (min_size, opt_size, max_size) for spatial dimensions
-        batch_requirements: Tuple of (min_batch, opt_batch, max_batch) for batch dimension
-    """
-    print(f"Building TensorRT engine for upscale model from ONNX model: {onnx_path}")
-    print("⚠️  WARNING: Transformer-based upscale models may not be compatible with TensorRT")
-    print(f"Size requirements: min={size_requirements[0]}, opt={size_requirements[1]}, max={size_requirements[2]}")
-    print(f"Batch requirements: min={batch_requirements[0]}, opt={batch_requirements[1]}, max={batch_requirements[2]}")
-    logger = trt.Logger(trt.Logger.WARNING)
-    builder = trt.Builder(logger)
-    network = builder.create_network(1 << int(trt.NetworkDefinitionCreationFlag.EXPLICIT_BATCH))
-    parser = trt.OnnxParser(network, logger)
-
-    # Analyze ONNX model
-    with open(onnx_path, "rb") as f:
-        if not parser.parse(f.read()):
-            for i in range(parser.num_errors):
-                print(parser.get_error(i), file=sys.stderr)
-            raise RuntimeError("Failed to parse the ONNX model")
-
-    # BuilderConfi
-    config = builder.create_builder_config()
-    config.set_memory_pool_limit(trt.MemoryPoolType.WORKSPACE, workspace)
-    if precision == "fp16" and builder.platform_has_fast_fp16:
-        config.set_flag(trt.BuilderFlag.FP16)
-    elif precision == "bf16" and builder.platform_has_fast_fp16:
-        config.set_flag(trt.BuilderFlag.BF16)
-    elif precision == "int8" and builder.platform_has_fast_int8:
-        config.set_flag(trt.BuilderFlag.INT8)
-    else:
-        config.set_flag(trt.BuilderFlag.TF32)
-
-    # Create optimization profile for dynamic shapes
-    profile = builder.create_optimization_profile()
-
-    # Get input tensor info
-    input_tensor = network.get_input(0)
-    input_name = input_tensor.name
-
-    print(f"Input tensor name: {input_name}")
-    print(f"Input tensor shape: {input_tensor.shape}")
-
-    # Analyze ONNX tensor shape to detect dynamic dimensions
-    onnx_shape = input_tensor.shape
-    shape_list = []
-    dynamic_dims = []
-
-    # Convert TensorRT Dims to list
-    for i in range(len(onnx_shape)):
-        dim = onnx_shape[i]
-        shape_list.append(dim)
-        if dim == -1:
-            dynamic_dims.append(i)
-
-    print(f"Shape list: {shape_list}")
-    print(f"Dynamic dimensions detected at axes: {dynamic_dims}")
-
-    if not dynamic_dims:
-        print("No dynamic dimensions found - no optimization profile needed")
-        # For static shapes, we don't need an optimization profile
-    else:
-        # Build optimization profile based on detected dynamic dimensions
-        min_size, opt_size, max_size = size_requirements
-        min_batch, opt_batch, max_batch = batch_requirements
-
-        min_shape = []
-        opt_shape = []
-        max_shape = []
-
-        for i, dim in enumerate(shape_list):
-            if dim == -1:  # Dynamic dimension
-                if i == 0:  # Batch dimension
-                    min_shape.append(min_batch)  # Minimum batch
-                    opt_shape.append(opt_batch)  # Optimal batch
-                    max_shape.append(max_batch)  # Maximum batch
-                elif i >= 2:  # Height/Width dimensions (assuming NCHW format)
-                    min_shape.append(min_size)  # Minimum spatial size
-                    opt_shape.append(opt_size)  # Optimal spatial size
-                    max_shape.append(max_size)  # Maximum spatial size
-                else:  # Other dynamic dimensions (likely channels)
-                    min_shape.append(1)
-                    opt_shape.append(3)  # Assume channels for face detection
-                    max_shape.append(4)
-            else:  # Static dimension
-                static_dim = int(dim)
-                min_shape.append(static_dim)
-                opt_shape.append(static_dim)
-                max_shape.append(static_dim)
-
-        min_shape = tuple(min_shape)
-        opt_shape = tuple(opt_shape)
-        max_shape = tuple(max_shape)
-
-        print("Optimization profile set:")
-        print(f"  Min shape: {min_shape}")
-        print(f"  Opt shape: {opt_shape}")
-        print(f"  Max shape: {max_shape}")
-
-        # Type: ignore for TensorRT Dims compatibility
-        profile.set_shape(input_name, min_shape, opt_shape, max_shape)  # type: ignore
-        config.add_optimization_profile(profile)
-
-    # Build engine
-    print("Building TensorRT engine... This may take several minutes.")
-    try:
-        engine_bytes = builder.build_serialized_network(network, config)
-        if engine_bytes is None:
-            raise RuntimeError("Engine build failed - no bytes returned")
-    except Exception as e:
-        error_msg = str(e).lower()
-        print(f"❌ TensorRT engine build failed: {e}")
-        print("\n💡 Troubleshooting suggestions:")
-
-        # Detect Transformer/Attention related errors
-        if any(keyword in error_msg for keyword in ["transpose", "reshape", "gather", "attention", "foreignnode"]):
-            print("\n🔍 DETECTED: Transformer/Attention model incompatibility")
-            print("   Your model appears to use Transformer operations (DAT, SwinIR, etc.)")
-            print("   that are not well supported by TensorRT.")
-            print("\n✅ RECOMMENDED SOLUTIONS:")
-            print("   1. 🚀 Use PyTorch inference instead (fastest option):")
-            print("      - Load model with spandrel and use model_desc(image)")
-            print("   2. 📦 Try ONNX Runtime for inference:")
-            print("      - onnxruntime-gpu provides good performance")
-            print("   3. 🔄 Convert to simpler architecture:")
-            print("      - Try ESRGAN, RealESRGAN, or EDSR models")
-            print("      - These CNN-based models work better with TensorRT")
-        else:
-            print("   1. Try using onnx_to_trt_fixed_shape() with a fixed input size")
-            print(f"   2. Reduce workspace size further (current: {workspace // 1024 // 1024}MB)")
-            print("   3. Try FP32 precision instead of FP16")
-            print("   4. Check if model operations are supported by TensorRT")
-            print("   5. Consider using smaller size_requirements:")
-            print("      - size_requirements=(64, 128, 256)")
-            print("      - Or fixed shape like (1, 3, 256, 256)")
-
-        raise RuntimeError(f"TensorRT build failed. See suggestions above. Error: {e}")
-
-    with open(engine_path, "wb") as f:
-        f.write(engine_bytes)
-
-    if not os.path.exists(engine_path):
-        raise RuntimeError(f"Failed to save TensorRT engine to {engine_path}")
-
-    print(f"✅ TensorRT upscale engine saved to: {engine_path}")
-
-
 def onnx_to_trt_fixed_shape(
     onnx_path: str,
     engine_path: str,
-    fixed_shape: tuple = (1, 3, 512, 512),
+    input_shape: tuple = (1, 3, 512, 512),
     precision: str = "fp16",
     workspace: int = 1024 << 20,
 ) -> None:
@@ -632,7 +485,7 @@ def onnx_to_trt_fixed_shape(
     """
 
     print(f"Building TensorRT engine with fixed shape from ONNX model: {onnx_path}")
-    print(f"Fixed input shape: {fixed_shape}")
+    print(f"Fixed input shape: {input_shape}")
 
     # Load and modify ONNX model to fix input shape
     model = onnx.load(onnx_path)
@@ -645,11 +498,11 @@ def onnx_to_trt_fixed_shape(
 
     # Create new input with fixed shape
     input_info.type.tensor_type.ClearField("shape")
-    for dim_size in fixed_shape:
+    for dim_size in input_shape:
         dim = input_info.type.tensor_type.shape.dim.add()
         dim.dim_value = int(dim_size)
 
-    print(f"Modified ONNX input to fixed shape: {fixed_shape}")
+    print(f"Modified ONNX input to fixed shape: {input_shape}")
 
     # Validate the modified model
     try:
@@ -706,8 +559,8 @@ def onnx_to_trt(
     input_shape: tuple | None = None,
     precision: str = "fp16",
     workspace: int = 512 << 20,
-    size_requirements: tuple = (16, 512, 2048),
-    batch_requirements: tuple = (1, 1, 1),
+    spatial_range: tuple = (16, 512, 2048),
+    batch_range: tuple = (1, 1, 1),
 ) -> None:
     """
     Convert ONNX model to TensorRT engine with automatic dynamic/fixed shape handling.
@@ -735,7 +588,7 @@ def onnx_to_trt(
         # Fixed shape TensorRT conversion
         try:
             onnx_to_trt_fixed_shape(
-                onnx_path=onnx_path, engine_path=engine_path, fixed_shape=input_shape, precision=precision, workspace=workspace
+                onnx_path=onnx_path, engine_path=engine_path, input_shape=input_shape, precision=precision, workspace=workspace
             )
         except Exception as e:
             print(f"\n❌ Fixed shape conversion failed: {e}")
@@ -753,8 +606,8 @@ def onnx_to_trt(
                 engine_path=engine_path,
                 precision=precision,
                 workspace=workspace,
-                size_requirements=size_requirements,
-                batch_requirements=batch_requirements,
+                spatial_range=spatial_range,
+                batch_range=batch_range,
             )
         except Exception as e:
             print(f"\n❌ Dynamic shape conversion failed: {e}")
