@@ -54,6 +54,7 @@ def guess_image_layout(image: cp.ndarray) -> Layout:
 
 def batch_to_images(
     batch: cp.ndarray,
+    size: int | tuple[int, int] | None = None,
     std: float | tuple[float, float, float] | None = None,
     mean: float | tuple[float, float, float] | None = None,
     swap_rb: bool = True,
@@ -100,6 +101,12 @@ def batch_to_images(
             elif len(mean) != 3:
                 raise ValueError("Mean must be a single value or a tuple of three values.")
             image += cp.array(mean, dtype=image.dtype)
+
+        if size is not None:
+            if isinstance(size, int):
+                size = (size, size)
+            image = resize(image, dsize=size, interpolation=INTER_AUTO)
+
         results.append(image)
 
     return results
